===============================
ejpiaj
===============================

.. image:: https://badge.fury.io/py/ejpiaj.png
    :target: http://badge.fury.io/py/ejpiaj
    
.. image:: https://travis-ci.org/onjin/ejpiaj.png?branch=master
        :target: https://travis-ci.org/onjin/ejpiaj

.. image:: https://pypip.in/d/ejpiaj/badge.png
        :target: https://crate.io/packages/ejpiaj?version=latest


ejpiaj

* Free software: BSD license

Features
--------

* test remote API with simple yaml files

Install
-------
* pip install ejpiaj

Simple usage
------------
Try it with sample file https://github.com/onjin/ejpiaj/blob/master/github.yml:

 * ejpiaj-cli test github.yml
